summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNirbheek Chauhan <nirbheek@centricular.com>2018-06-11 00:06:02 +0530
committerNirbheek Chauhan <nirbheek@centricular.com>2018-06-11 00:20:22 +0530
commit176087e7c44a98daa4609e77fbfb6bb79ca8aef2 (patch)
tree0625885a6f10e0f4434c8202e5ae7d2795d00df0
parent105b966fa4343ff6fe49927eef5b84981237be5d (diff)
downloadmeson-nirbheek/macos-rpath-uninstalled.tar.gz
unittests: Assert that we have pkg-config on all CInirbheek/macos-rpath-uninstalled
Our appveyor configuration provides pkg-config when building for mingw, cygwin, msvc, etc. Of course, people manually running the tests won't require pkg-config.
-rwxr-xr-xrun_unittests.py17
1 files changed, 12 insertions, 5 deletions
diff --git a/run_unittests.py b/run_unittests.py
index c8df941f4..af2195e7c 100755
--- a/run_unittests.py
+++ b/run_unittests.py
@@ -74,15 +74,22 @@ def get_soname(fname):
def get_rpath(fname):
return get_dynamic_section_entry(fname, r'(?:rpath|runpath)')
+def is_ci():
+ if 'TRAVIS' in os.environ or 'APPVEYOR' in os.environ:
+ return True
+ return False
+
def skipIfNoPkgconfig(f):
'''
- Skip this test if no pkg-config is found, unless we're on Travis CI
- This allows users to run our test suite without having pkg-config installed
- on, f.ex., macOS, while ensuring that our Travis CI does not silently skip
- the test because of misconfiguration.
+ Skip this test if no pkg-config is found, unless we're on Travis or
+ Appveyor CI. This allows users to run our test suite without having
+ pkg-config installed on, f.ex., macOS, while ensuring that our CI does not
+ silently skip the test because of misconfiguration.
+
+ Note: Yes, we provide pkg-config even while running Windows CI
'''
def wrapped(*args, **kwargs):
- if 'TRAVIS' not in os.environ and shutil.which('pkg-config') is None:
+ if is_ci() and shutil.which('pkg-config') is None:
raise unittest.SkipTest('pkg-config not found')
return f(*args, **kwargs)
return wrapped